@@ -395,6 +395,7 @@ class Contract(BaseContent):
 
         Will return None if start date or duration is not known.
         """
+       
         start = self.getStartdate()
         duration = self.getDuration()
         if start is None or duration is None:
@@ -412,7 +413,7 @@ class Contract(BaseContent):
             date -= 1
         if not safety_count:
             return None
-        return date
+        return date - 1
 
     security.declarePublic('hour_spread')
     @property
