@@ -1,7 +1,7 @@
 from zope.i18n import translate
 from zope.interface import implements
 from zope.component.interfaces import ObjectEvent
-
+from Acquisition import aq_parent
 from Products.CMFCore.utils import getToolByName
 
 from plonehrm.contracts import ContractsMessageFactory as _
@@ -23,15 +23,34 @@ class ContractEndingEvent(ObjectEvent):
 
     def __init__(self, *args, **kwargs):
         super(ContractEndingEvent, self).__init__(*args, **kwargs)
+
+        # We get the settings of the worklocaton to see
+        # if a new letter or a new contract shall be created.
+        worklocation = aq_parent(self.object)
+
+        if worklocation.getCreateLetterWhenExpiry():
+            new_type = 'Letter'
+            text = _('msg_make_new_letter', u"Make new letter")
+        else:
+            new_type = 'Contract'
+            text = _('msg_make_new_contract', u"Make new contract")
+        
         create_url = self.object.absolute_url() + \
-            '/createObject?type_name=Contract'
-        contracts = self.object.restrictedTraverse('@@contracts')
-        expires = contracts.expires()
+            '/createObject?type_name=' + new_type
+            
+        # Get the expiry date.
+        last_contract = self.object.get_last_contract()
+        if not last_contract:
+            # Should not happen.
+            expires = None
+        else:
+            expires = last_contract.expiry_date()
+
         # Add a message to make a new contract, with the correct link.
-        text = _('msg_make_new_contract', u"Make new contract")
         props = getToolByName(self.object, 'portal_properties')
         lang = props.site_properties.getProperty('default_language')
         text = translate(text, target_language=lang)
+
         self.message = text
         self.link_url = create_url
         self.date = expires
